@@ -5,6 +5,7 @@
 # Released under the MIT license.
 
 from time import strptime
+from json import loads
 import requests
 from bs4 import BeautifulSoup
 
@@ -47,3 +48,34 @@ def stock_price_prediction():
     """
     return choice([-1, 1])
 
+
+def get_wf_json(url = "https://www.jma.go.jp/bosai/forecast/data/forecast/130000.json"):
+    resp = requests.get(url)
+    d = loads(resp.text)
+    return d
+
+
+
+def pp():
+    """
+    東京の直近の降水確率を返す
+    """
+    d = get_wf_json()
+    return int(d[0]["timeSeries"][1]["areas"][0]["pops"][0])
+
+
+def temp():
+    """
+    東京の直近の気温予測を返す
+    """
+    d = get_wf_json()
+    c = int(d[0]["timeSeries"][2]["areas"][0]["temps"][0])
+    return int(1.8*c+32)
+
+
+def f2c(f):
+    """
+    華氏(Fahrenheit)から摂氏(Celsius)に変換
+    """
+    return int((f-32)*(5/9))
+
